@@ -7,7 +7,7 @@ from sam2lca.config import NCBI
 from pathlib import Path
 
 
-def sam2lca(sam, mappings, tree, process, identity, length, dbdir, output):
+def sam2lca(sam, mappings, tree, process, identity, length, conserved, dbdir, output):
     """Performs LCA on SAM/BAM/CRAM alignment file
 
     Args:
@@ -25,17 +25,15 @@ def sam2lca(sam, mappings, tree, process, identity, length, dbdir, output):
     utils.check_extension(sam)
     al = Alignment(al_file=sam)
     read_dict = al.get_reads(
-        process=process, identity=identity, minlength=length)
+        process=process, identity=identity, minlength=length, check_conserved=conserved
+    )
     acc2tax_db = f"{dbdir}/{map_db[mappings]}"
     p = Path(acc2tax_db)
     if not p.exists():
         print(f"'{acc2tax_db}' database seems to be missing, I'm creating it for you.")
         get_mapping(mappings, dbdir=dbdir, update=False)
-    reads_taxid_dict = compute_lca_multi(read_dict,
-                                         acc2tax_db,
-                                         tree,
-                                         process)
-    taxid_counts = utils.count_reads_taxid(reads_taxid_dict)
+    reads_taxid_dict = compute_lca_multi(read_dict, acc2tax_db, tree, process)
+    taxid_counts, taxid_reads = utils.count_reads_taxid(reads_taxid_dict)
     utils.taxid_to_lineage(taxid_counts, output)
 
 
